@@ -1,5 +1,5 @@
 package Business::PayPal::API;
-$Business::PayPal::API::VERSION = '0.71_01'; # TRIAL
+$Business::PayPal::API::VERSION = '0.71_02'; # TRIAL
 use 5.008001;
 use strict;
 use warnings;
@@ -303,7 +303,7 @@ Business::PayPal::API - PayPal SOAP API client with sandbox support
 
 =head1 VERSION
 
-version 0.71_01
+version 0.71_02
 
 =head1 SYNOPSIS
 
@@ -782,9 +782,6 @@ module in some way:
 for authoring the AuthorizationRequest, CaptureRequest,
 DirectPayments, ReauthorizationRequest, and VoidRequest extensions.
 
-Danny's contact information may be found in the AUTHOR section of the
-above modules.
-
 =item * <jshiles at base16consulting daught com>
 
 for finding some API typos in the ExpressCheckout API
@@ -828,18 +825,6 @@ L<https://www.paypal.com/IntegrationCenter/ic_expresscheckout.html>,
 L<https://www.sandbox.paypal.com/en_US/pdf/PP_Sandbox_UserGuide.pdf>,
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
-
-Scott Wiersdorf, E<lt>scott@perlcode.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2006, 2007 by Scott Wiersdorf
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
-
 =head1 AUTHORS
 
 =over 4
@@ -854,13 +839,13 @@ Danny Hembree <danny@dynamical.org>
 
 =item *
 
-Bradley M. Kuhn bkuhn@ebb.org
+Bradley M. Kuhn <bkuhn@ebb.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Scott Wiersdorf, Danny Hembree.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
