@@ -1,5 +1,5 @@
 package Business::PayPal::API::ExpressCheckout;
-$Business::PayPal::API::ExpressCheckout::VERSION = '0.71_01'; # TRIAL
+$Business::PayPal::API::ExpressCheckout::VERSION = '0.71_02'; # TRIAL
 use 5.008001;
 use strict;
 use warnings;
@@ -376,7 +376,7 @@ Business::PayPal::API::ExpressCheckout - PayPal Express Checkout API
 
 =head1 VERSION
 
-version 0.71_01
+version 0.71_02
 
 =head1 SYNOPSIS
 
@@ -603,13 +603,13 @@ Danny Hembree <danny@dynamical.org>
 
 =item *
 
-Bradley M. Kuhn bkuhn@ebb.org
+Bradley M. Kuhn <bkuhn@ebb.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Scott Wiersdorf, Danny Hembree.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
